package com.muyu.quest.controller;

import java.util.Arrays;
import java.util.List;

import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.quest.domain.Task;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;

import com.muyu.quest.service.TaskService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 任务Controller
 *
 * @author 2112A
 * @date 2024-08-22
 */
@RestController
@RequestMapping("/quest")
public class TaskController extends BaseController
{
    @Resource
    private TaskService taskService;

    /**
     * 查询任务列表
     */
//    @RequiresPermissions("quest:quest:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Task>> list(Task task)
    {
        startPage();
        List<Task> list = taskService.selectTaskList(task);
        return getDataTable(list);
    }

    /**
     * 获取任务详细信息
     */
//    @RequiresPermissions("quest:quest:query")
    @GetMapping(value = "selectTaskByTaskCode/{taskCode}")
    public Result<List<Task>> getInfo(@PathVariable("taskCode") String taskCode) {
        return success(taskService.selectTaskByTaskCode(taskCode));
    }

    /**
     * 获取任务详细信息
     */
//    @RequiresPermissions("quest:quest:query")
    @GetMapping(value = "selectTaskById/{id}")
    public Result<List<Task>> getInfo(@PathVariable("id") Long id) {
        return success(taskService.selectTaskById(id));
    }

    /**
     * 新增任务
     */
//    @RequiresPermissions("quest:quest:quest")
    @PostMapping
    public Result<Integer> add (@Validated @RequestBody Task task) {
        if (taskService.checkTaskCodeUnique(task)) {
            return error("新增参数'" + task.getTaskName() + "'失败，任务已存在");
        }
        task.setCreateBy(SecurityUtils.getUsername());
        return toAjax(taskService.save(task));
    }

    /**
     * 修改参数配置
     */
//    @RequiresPermissions("quest:quest:quest")
    @PutMapping
    public Result edit (@Validated @RequestBody Task task) {
        if (!taskService.checkIdUnique(task)) {
            return error("修改参数'" + task.getTaskName() + "'失败，任务不存在");
        }
        task.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(taskService.updateById(task));
    }

    /**
     * 删除参数配置
     */
//    @RequiresPermissions("system:task:remove")
    @DeleteMapping("/{taskIds}")
    public Result remove (@PathVariable("taskIds") Long[] taskIds) {
        taskService.removeBatchByIds(Arrays.asList(taskIds));
        return success();
    }

}
