package com.muyu.quest.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.stereotype.Service;
import com.muyu.quest.mapper.TaskMapper;
import com.muyu.quest.domain.Task;
import com.muyu.quest.service.TaskService;
import org.springframework.util.Assert;

/**
 * 任务Service业务层处理
 *
 * @author 2112A
 * @date 2024-08-22
 */
@Service
public class TaskServiceImpl extends ServiceImpl<TaskMapper, Task>
        implements TaskService {

    /**
     * 查询任务
     *
     * @param taskCode 任务编码
     * @return 任务
     */
    @Override
    public Task selectTaskByTaskCode(String taskCode)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(taskCode, "taskCode不可为空");
        queryWrapper.eq(Task::getTaskCode, taskCode);
        return this.getOne(queryWrapper);
    }

    /**
     * 查询任务
     *
     * @param id 任务主键
     * @return 任务
     */
    @Override
    public Task selectTaskById(Long id)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(Task::getId, id);
        return this.getOne(queryWrapper);
    }

    /**
     * 唯一编码判断
     * @param task
     * @return
     */
    @Override
    public Boolean checkTaskCodeUnique(Task task) {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Task::getTaskCode, task.getTaskCode());
        return this.count(queryWrapper) > 0;
    }

    @Override
    public Boolean checkIdUnique(Task task) {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Task::getId, task.getId());
        return this.count(queryWrapper) > 0;
    }

    /**
     * 查询任务列表
     *
     * @param task 任务
     * @return 任务
     */
    @Override
    public List<Task> selectTaskList(Task task)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(task.getTaskName())){
            queryWrapper.like(Task::getTaskName, task.getTaskName());
        }
        if (StringUtils.isNotEmpty(task.getRuleCode())){
            queryWrapper.eq(Task::getRuleCode, task.getRuleCode());
        }
        if (StringUtils.isNotEmpty(task.getState())){
            queryWrapper.eq(Task::getState, task.getState());
        }
        if (StringUtils.isNotEmpty(task.getTaskType())){
            queryWrapper.eq(Task::getTaskType, task.getTaskType());
        }
        return this.list(queryWrapper);
    }


}
